# Copyright (C) 2026 ATIL İHSAN YALI
# This file is part of NeuroFHIR.
# AGPL-3.0 License.

from setuptools import setup

# minimal setup.py, configuration is in pyproject.toml
if __name__ == "__main__":
    setup()
